@@ -1,4 +1,3 @@
-/* $Xorg: io.c,v 1.5 2001/02/09 02:05:44 xorgcvs Exp $ */
 /*
  * i/o functions
  */
@@ -46,20 +45,17 @@ in this Software without prior written authorization from The Open Group.
  * ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
  * THIS SOFTWARE.
  */
-/* $XFree86: xc/programs/xfs/os/io.c,v 3.18 2001/12/14 20:01:41 dawes Exp $ */
+
+#include	"xfs-config.h"
 
 #include	<X11/Xtrans/Xtrans.h>
 #include	<stdio.h>
 #include	<errno.h>
 #include	<sys/types.h>
-#ifndef Lynx
 #include	<sys/param.h>
 #ifndef __UNIXOS2__
 #include	<sys/uio.h>
 #endif
-#else
-#include	<uio.h>
-#endif
 
 #include	<X11/fonts/FSproto.h>
 #include	"clientstr.h"
@@ -85,23 +81,12 @@ in this Software without prior written authorization from The Open Group.
 
 #endif
 
-
-extern fd_set ClientsWithInput;
-extern fd_set ClientsWriteBlocked;
-extern fd_set OutputPending;
-
-extern long OutputBufferSize;
-
-extern int  ConnectionTranslation[];
-
-extern Bool AnyClientsWriteBlocked;
-extern Bool NewOutputPending;
-
 static int  timesThisConnection = 0;
 static ConnectionInputPtr FreeInputs = (ConnectionInputPtr) NULL;
 static ConnectionOutputPtr FreeOutputs = (ConnectionOutputPtr) NULL;
 static OsCommPtr AvailableInput = (OsCommPtr) NULL;
 
+extern int xfd_ffs(fd_mask);
 static ConnectionInputPtr AllocateInputBuffer(void);
 static ConnectionOutputPtr AllocateOutputBuffer(void);
 
@@ -540,9 +525,9 @@ FlushAllOutput(void)
 	mask = OutputPending.fds_bits[base];
 	OutputPending.fds_bits[base] = 0;
 	while (mask) {
-	    index = ffs(mask) - 1;
+	    index = xfd_ffs(mask) - 1;
 	    mask &= ~lowbit(mask);
-	    if ((index = ConnectionTranslation[(base << 5) + index]) == 0)
+	    if ((index = ConnectionTranslation[(base * (sizeof(fd_mask) * 8)) + index]) == 0)
 		continue;
 	    client = clients[index];
 	    if (client->clientGone == CLIENT_GONE)
@@ -628,7 +613,7 @@ AllocateInputBuffer(void)
 	fsfree(oci);
 	return (ConnectionInputPtr) NULL;
     }
-    oci->next = 0;
+    oci->next = NULL;
     oci->size = BUFSIZE;
     oci->bufptr = oci->buffer;
     oci->bufcnt = 0;
